@@ -8,16 +8,16 @@
  * the search strongly toward the destination rather than
  * propagating isotropically from the starting points.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
@@ -28,7 +28,8 @@ static char sccsid[] = "@(#)grouteNet.c	4.3 MAGIC (Berkeley) 12/6/85";
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/times.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -39,14 +40,14 @@ static char sccsid[] = "@(#)grouteNet.c	4.3 MAGIC (Berkeley) 12/6/85";
 #include "database/database.h"
 #include "gcr/gcr.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 
 Point glDestPoint;	/* Point we're routing to */
 
@@ -104,7 +105,7 @@ int fudgeDenom = 10;
 
 /* Marker to indicate an already-processed GlPoint */
 #define	PROCESSED_MARK	((GlPoint *) 1)
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -131,14 +132,14 @@ int fudgeDenom = 10;
 
 GlPoint *
 glRouteToPoint(loc, bestCost)
-    register NLTermLoc *loc;	/* Route from points on heap to this point */
+    NLTermLoc *loc;	/* Route from points on heap to this point */
     int bestCost;		/* If we haven't found a path with less than
 				 * this cost, return NULL.
 				 */
 {
     int heapPts, frontierPts, startPts, headFree;
-    register GCRChannel *inCh;
-    register GlPoint *inPt;
+    GCRChannel *inCh;
+    GlPoint *inPt;
     bool newBest, newPaths;
     HeapEntry hEntry;
     GlPage *headPage;
@@ -150,7 +151,7 @@ glRouteToPoint(loc, bestCost)
 
     glNumTries++;
     if (glLogFile)
-	(void) fprintf(glLogFile, "---\t%d\t0,0\t0\t0\n", glNumTries);
+	fprintf(glLogFile, "---\t%d\t0,0\t0\t0\n", glNumTries);
 
     /* Initialization */
     if (!glPenaltiesScaled)
@@ -240,12 +241,12 @@ glRouteToPoint(loc, bestCost)
 	glHistoAdd(heapPts, frontierPts, startPts);
 
     /* Free the auxiliary heaps */
-    HeapKill(&glBestHeap, (void (*)()) NULL);
-    HeapKill(&glProximityHeap, (void (*)()) NULL);
+    HeapKill(&glBestHeap, (cb_heap_kill_t) NULL);
+    HeapKill(&glProximityHeap, (cb_heap_kill_t) NULL);
 
     return (lastPt);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -263,7 +264,7 @@ glRouteToPoint(loc, bestCost)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glScalePenalties()
 {
     glJogPenalty *= RtrGridSpacing;
@@ -275,7 +276,7 @@ glScalePenalties()
     glChanPenalty *= RtrGridSpacing;
     glPenaltiesScaled = TRUE;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -345,7 +346,7 @@ glPopFromHeap(pNewBest, newPaths, hEntry)
     if (*pNewBest)
     {
 	/*
-	 * Pop bestcost heap until path that hasn't already been 
+	 * Pop bestcost heap until path that hasn't already been
 	 * processed is reached.   (Already processed paths are marked
 	 * by setting their gl_next field to PROCESSED_MARK).  This
 	 * point will be the one with the best possible cost plus
@@ -408,7 +409,7 @@ glPopFromHeap(pNewBest, newPaths, hEntry)
 	 * The minimum acceptable cost for transfer from the
 	 * Reserve heap (glHeap) to the proximity and best heaps
 	 * will be glBestCost * (fudgeNumer / fudgeDenom).
-	 */ 
+	 */
 	minAcceptableCost = (glBestCost * fudgeNumer) / fudgeDenom;
 	if (DebugIsSet(glDebugID, glDebHeap))
 	    TxPrintf("Min acceptable cost = %d\n", minAcceptableCost);
@@ -469,7 +470,7 @@ glPopFromHeap(pNewBest, newPaths, hEntry)
     }
     return TRUE;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -535,7 +536,7 @@ glFinalPropagate(inPt, loc)
     HeapAddInt(&glHeap, cost, (char *) outPt);
     if (glLogFile)
     {
-	(void) fprintf(glLogFile, "FIN\t%d\t%d,%d\t%d\n",
+	fprintf(glLogFile, "FIN\t%d\t%d,%d\t%d\n",
 		glNumTries,
 		outPt->gl_point.p_x, outPt->gl_point.p_y,
 		outPt->gl_length);
@@ -543,7 +544,7 @@ glFinalPropagate(inPt, loc)
 
     return (TRUE);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -565,11 +566,11 @@ glFinalPropagate(inPt, loc)
 
 int
 glRiverPropagate(inPt)
-    register GlPoint *inPt;
+    GlPoint *inPt;
 {
-    register GCRPin *inPin = inPt->gl_pin, *outPin, *linkedPin;
-    register GCRChannel *inCh = inPt->gl_ch;
-    register int cost;
+    GCRPin *inPin = inPt->gl_pin, *outPin, *linkedPin;
+    GCRChannel *inCh = inPt->gl_ch;
+    int cost;
     GlPoint *outPt;
 
     /* Find the opposing pin */
@@ -599,7 +600,7 @@ glRiverPropagate(inPt)
 	    HeapAddInt(&glHeap, cost, (char *) outPt);
 	    if (glLogFile)
 	    {
-		(void) fprintf(glLogFile, "RIV\t%d\t%d,%d\t%d\t%d\n",
+		fprintf(glLogFile, "RIV\t%d\t%d,%d\t%d\t%d\n",
 			glNumTries,
 			outPt->gl_point.p_x, outPt->gl_point.p_y,
 			outPt->gl_length, cost);
@@ -610,7 +611,7 @@ glRiverPropagate(inPt)
 
     return (-1);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -717,18 +718,18 @@ glRiverPropagate(inPt)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glNormalPropagate(inPt, inCh, heapCost)
-    register GlPoint *inPt;	/* Point on the boundary of inCh */
-    register GCRChannel *inCh;	/* Channel through which we're passing */
+    GlPoint *inPt;	/* Point on the boundary of inCh */
+    GCRChannel *inCh;	/* Channel through which we're passing */
     int heapCost;		/* Cost with which inPt was added to heap */
 {
     PinRanges pinRange, prevRange;
     int x, y, baseCost, min, max;
     GCRPin *inPin = inPt->gl_pin;
     Rect pinRect, densRect;
-    register GCRPin *outPin;
-    register int i, cost;
+    GCRPin *outPin;
+    int i, cost;
     bool noCheckJogs;
 
     /*
@@ -888,7 +889,7 @@ glNormalPropagate(inPt, inCh, heapCost)
     }
     else glCrossingsComplete++;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -914,11 +915,11 @@ glNormalPropagate(inPt, inCh, heapCost)
 int
 glMinRemainingCost(inPt, inCh, pRect, dRect)
     GlPoint *inPt;
-    register GCRChannel *inCh;
-    register Rect *pRect, *dRect;
+    GCRChannel *inCh;
+    Rect *pRect, *dRect;
 {
-    register int cost, n;
-    register GCRPin *pins;
+    int cost, n;
+    GCRPin *pins;
 
     /*
      * In the code below, 'cost' represents the sum of the cost
@@ -1042,11 +1043,11 @@ glMinRemainingCost(inPt, inCh, pRect, dRect)
 
 int
 glPinCost(inPt, pin, oldCost)
-    register GlPoint *inPt;
-    register GCRPin *pin;
+    GlPoint *inPt;
+    GCRPin *pin;
     int oldCost;
 {
-    register int cost;
+    int cost;
 
     /* Length from inPt to pin */
     cost = ABSDIFF(inPt->gl_point.p_x, pin->gcr_point.p_x)
@@ -1064,7 +1065,7 @@ glPinCost(inPt, pin, oldCost)
 
     return (MIN(cost, oldCost));
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1090,12 +1091,12 @@ glPinCost(inPt, pin, oldCost)
 bool
 glSetDensityClip(inPt, ch, dRect)
     GlPoint *inPt;
-    register GCRChannel *ch;
-    register Rect *dRect;
+    GCRChannel *ch;
+    Rect *dRect;
 {
     GCRPin *inPin = inPt->gl_pin;
-    register short *den, maxdensity;
-    register int n;
+    short *den, maxdensity;
+    int n;
 
     /*
      * Default: in the absence of density violations, we can
@@ -1166,7 +1167,7 @@ glSetDensityClip(inPt, ch, dRect)
 
     return (dRect->r_xtop >= dRect->r_xbot && dRect->r_ytop >= dRect->r_ybot);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1211,12 +1212,12 @@ glSetDensityClip(inPt, ch, dRect)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glSetPinClip(inPt, inCh, heapCost, dRect, pRect)
-    register GlPoint *inPt;
-    register GCRChannel *inCh;
+    GlPoint *inPt;
+    GCRChannel *inCh;
     int heapCost;
-    register Rect *dRect, *pRect;
+    Rect *dRect, *pRect;
 {
     int bloat, estCost, t;
     Rect r;
@@ -1252,7 +1253,7 @@ glSetPinClip(inPt, inCh, heapCost, dRect, pRect)
     /* Clip against dRect */
     GEOCLIP(pRect, dRect);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1270,14 +1271,14 @@ glSetPinClip(inPt, inCh, heapCost, dRect, pRect)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glResetCost(headPage, headFree)
     GlPage *headPage;
     int headFree;
 {
-    register GlPage *gpage;
-    register GCRPin *pin;
-    register int n;
+    GlPage *gpage;
+    GCRPin *pin;
+    int n;
 
     for (gpage = headPage; gpage; gpage = gpage->glp_next)
     {
@@ -1293,7 +1294,7 @@ glResetCost(headPage, headFree)
 	headFree = 0;
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1316,10 +1317,10 @@ glResetCost(headPage, headFree)
 int
 glPropagateFn(outCh, outPin, inPt)
     GCRChannel *outCh;		/* Channel entered from outPin */
-    register GCRPin *outPin;	/* Exit pin, also in inCh */
-    register GlPoint *inPt;	/* Point being considered */
+    GCRPin *outPin;	/* Exit pin, also in inCh */
+    GlPoint *inPt;	/* Point being considered */
 {
-    register int cost, n;
+    int cost, n;
     int finalCost;
     GlPoint *outPt;
 
@@ -1370,14 +1371,14 @@ glPropagateFn(outCh, outPin, inPt)
     HeapAddInt(&glHeap, finalCost, (char *) outPt);
     if (glLogFile)
     {
-	(void) fprintf(glLogFile, "ADD\t%d\t%d,%d\t%d\t%d\n",
+	fprintf(glLogFile, "ADD\t%d\t%d,%d\t%d\t%d\n",
 		glNumTries,
 		outPt->gl_point.p_x, outPt->gl_point.p_y,
 		outPt->gl_length, finalCost);
     }
     return (finalCost);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1408,10 +1409,10 @@ glCrossPenalty(cost, inCh, outCh, inPin, outPin)
     GCRChannel *outCh;		/* Channel to which outPin exits, or NULL
 				 * if outPin is the destination.
 				 */
-    register GCRPin *inPin;	/* Pin used to enter inCh */
-    register GCRPin *outPin;	/* Pin used to exit inCh into outCh */
+    GCRPin *inPin;	/* Pin used to enter inCh */
+    GCRPin *outPin;	/* Pin used to exit inCh into outCh */
 {
-    register GCRPin *otherPin;
+    GCRPin *otherPin;
     int count;
 
     /* Penalty for using lots of channels */
@@ -1497,7 +1498,7 @@ glCrossPenalty(cost, inCh, outCh, inPin, outPin)
 
     return (cost);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1519,10 +1520,10 @@ glCrossPenalty(cost, inCh, outCh, inPin, outPin)
 bool
 glDensityExceeded(inCh, inPin, outPin)
     GCRChannel *inCh;
-    register GCRPin *inPin, *outPin;
+    GCRPin *inPin, *outPin;
 {
     int min, max, maxdensity;
-    register short *den;
+    short *den;
     short *dlast;
 
     if (inCh->gcr_dMaxByRow >= inCh->gcr_length)
@@ -1562,7 +1563,7 @@ glDensityExceeded(inCh, inPin, outPin)
 
     return (FALSE);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1588,11 +1589,11 @@ glDensityExceeded(inCh, inPin, outPin)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glRectToRange(ch, r, pr)
-    register GCRChannel *ch;
-    register Rect *r;
-    register PinRanges *pr;
+    GCRChannel *ch;
+    Rect *r;
+    PinRanges *pr;
 {
     Rect clipR;
 
@@ -1621,7 +1622,7 @@ glRectToRange(ch, r, pr)
     if (r->r_xtop == ch->gcr_length + 1)
 	pr->pr_rmin = clipR.r_ybot, pr->pr_rmax = clipR.r_ytop;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1642,7 +1643,7 @@ glRectToRange(ch, r, pr)
 
 bool
 glJogsAcrossChannel(inPin, outPin)
-    register GCRPin *inPin, *outPin;
+    GCRPin *inPin, *outPin;
 {
     switch (inPin->gcr_side)
     {
@@ -1670,7 +1671,7 @@ glJogsAcrossChannel(inPin, outPin)
 
     return (FALSE);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1689,7 +1690,7 @@ glJogsAcrossChannel(inPin, outPin)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glPropagateDebug(inPt, inPin, outCh, outPin, prevCost, distCost)
     GlPoint *inPt;
     GCRPin *inPin, *outPin;
@@ -1731,7 +1732,7 @@ glPropagateDebug(inPt, inPin, outCh, outPin, prevCost, distCost)
     nrMore(mesg);
     nrShowRect(EditCellUse->cu_def, &r, STYLE_ERASEHIGHLIGHTS);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1750,22 +1751,22 @@ glPropagateDebug(inPt, inPin, outCh, outPin, prevCost, distCost)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glLogPath(inPt, cost)
-    register GlPoint *inPt;
+    GlPoint *inPt;
     int cost;
 {
     extern Rect glInitRect;
 
     if (bcmp((char *)&inPt->gl_range, (char *)&glInitRect, sizeof (Rect)) == 0)
     {
-	(void) fprintf(glLogFile, "TOP\t%d\t%d,%d\t%d\t%d\n",
+	fprintf(glLogFile, "TOP\t%d\t%d,%d\t%d\t%d\n",
 		glNumTries,
 		inPt->gl_point.p_x, inPt->gl_point.p_y,
 		inPt->gl_length, cost);
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1782,9 +1783,9 @@ glLogPath(inPt, cost)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glPrintPoint(inPt)
-    register GlPoint *inPt;
+    GlPoint *inPt;
 {
     TxPrintf("(%d,%d) l=%d p=0x%x c=0x%x",
 	inPt->gl_point.p_x, inPt->gl_point.p_y,
